package com.simuwang.shiro.core.bridge;

import cn.hutool.core.bean.BeanUtil;
import com.simuwang.base.pojo.SysUser;
import com.simuwang.shiro.core.ShiroUser;
import com.simuwang.shiro.core.adapter.AuthAdapter;
import org.apache.shiro.authz.AuthorizationInfo;
import org.apache.shiro.authz.SimpleAuthorizationInfo;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author wangzaijun
 * @date 2024/9/6 17:42
 * @description 授权与认证的用户信息桥接接口
 */
@Service
public class AuthBridgeService {
    private final AuthAdapter authAdapter;

    public AuthBridgeService(AuthAdapter authAdapter) {
        this.authAdapter = authAdapter;
    }

    public ShiroUser findUserByUsername(String username) {
        SysUser sysUser = this.authAdapter.findUserByUsername(username);
        return BeanUtil.copyProperties(sysUser, ShiroUser.class);
    }

    public AuthorizationInfo getAuthorizationInfo(ShiroUser shiroUser) {
        //查询用户对应的角色标识
        List<String> roleList = this.findRoles(shiroUser.getUserId());
        //查询用户对于的资源标识
        List<String> resourcesList = this.findPermissions(shiroUser.getUserId());
        //构建鉴权信息对象
        SimpleAuthorizationInfo simpleAuthorizationInfo = new SimpleAuthorizationInfo();
        simpleAuthorizationInfo.addRoles(roleList);
        simpleAuthorizationInfo.addStringPermissions(resourcesList);
        return simpleAuthorizationInfo;
    }

    public List<String> findRoles(String userId) {
        return this.authAdapter.findRoleByUserId(userId);
    }

    public List<String> findPermissions(String userId) {
        return this.authAdapter.findPermissionsByUserId(userId);
    }
}
