package com.simuwang.shiro.core.impl;

import com.simuwang.shiro.core.ShiroDbRealm;
import com.simuwang.shiro.core.ShiroToken;
import com.simuwang.shiro.core.ShiroUser;
import com.simuwang.shiro.core.bridge.AuthBridgeService;
import org.apache.shiro.authc.*;
import org.apache.shiro.authc.credential.HashedCredentialsMatcher;
import org.apache.shiro.authz.AuthorizationInfo;
import org.apache.shiro.lang.util.ByteSource;
import org.apache.shiro.subject.PrincipalCollection;
import org.springframework.stereotype.Component;

@Component
public class ShiroDbRealmImpl extends ShiroDbRealm {
    private final AuthBridgeService authBridgeService;

    public ShiroDbRealmImpl(AuthBridgeService authBridgeService) {
        this.authBridgeService = authBridgeService;
    }

    @Override
    public AuthorizationInfo doGetAuthorizationInfo(PrincipalCollection principals) {
        ShiroUser shiroUser = (ShiroUser) principals.getPrimaryPrincipal();
        return this.authBridgeService.getAuthorizationInfo(shiroUser);
    }

    @Override
    public AuthenticationInfo doGetAuthenticationInfo(AuthenticationToken authenticationToken) throws AuthenticationException {
        ShiroToken token = (ShiroToken) authenticationToken;
        ShiroUser shiroUser = this.authBridgeService.findUserByUsername(token.getUsername());
        if (shiroUser == null) {
            throw new UnknownAccountException("账号不存在");
        }
        shiroUser.setPermissionCodes(this.authBridgeService.findPermissions(shiroUser.getUserId()));
        String salt = shiroUser.getSalt();
        String password = shiroUser.getPassword();
        return new SimpleAuthenticationInfo(shiroUser, password, ByteSource.Util.bytes(salt), getName());
    }

    @Override
    public void initCredentialsMatcher() {
        HashedCredentialsMatcher matcher = new HashedCredentialsMatcher("bcrypt");
        matcher.setHashIterations(1000);
        setCredentialsMatcher(matcher);
    }
}
